@@ -1,3 +1,6 @@
+# need d as global because data=d in function def does not 
+#  have a value assigned to d, d <- mydata does do that, even if conditional
+#  generates a Note
 if (getRversion() >= "3.5.0")
   globalVariables(c("d", "mydata", "l", "mylabels", "mycor"))
 
@@ -6,7 +9,7 @@ if (getRversion() >= "3.5.0")
 function(...) {
 
   packageStartupMessage("\n",
-      "lessR 4.0.3  feedback: gerbing@pdx.edu  web: lessRstats.com/new\n",
+      "lessR 4.0.5  feedback: gerbing@pdx.edu  web: lessRstats.com/new\n",
       "---------------------------------------------------------------\n",
       "> d <- Read(\"\")   Read text, Excel, SPSS, SAS, or R data file\n",
       "  d is default data frame, data= in analysis routines optional\n",
@@ -46,9 +49,9 @@ function(...) {
   options(values_digits = NULL)
   options(values_position = "in")
 
-  options(pt_fill = rgb(45,88,105, maxColorValue=255))
+  options(pt_fill = rgb(50,78,92, maxColorValue=255))
   options(trans_pt_fill = 0.00)
-  options(pt_color = rgb(45,88,105, maxColorValue=255))  # old 70 80 90
+  options(pt_color = rgb(50,78,92, maxColorValue=255))  # old 70 80 90
   options(out_fill = "firebrick4")
   options(out_color = "firebrick4")
   options(out2_fill = "firebrick2")
@@ -65,7 +68,7 @@ function(...) {
   options(ellipse_color = "gray20")
   options(ellipse_lwd = 1)
   options(se_fill = "#1A1A1A19")  # old .maketrans("gray10", 40) "darkblue", 25
-  options(fit_color = rgb(125,120,110, maxColorValue = 255))
+  options(fit_color = rgb(92,64,50, maxColorValue = 255))
   options(fit_lwd = 2)
   options(heat = "gray30")
   options(segment_color = "gray40")
@@ -1109,11 +1112,12 @@ function(dir, axT) {
 
 
 # axis labels
-.axlabs <- function(x.lab, y.lab, main.lab, sub.lab, max.lbl.y,
+.axlabs <- function(x.lab, y.lab, main.lab, sub.lab, 
                     x.val=NULL, xy_ticks=TRUE, offset=0.5,
                     lab_x_cex=NULL, lab_y_cex=NULL, main_cex=NULL,
                     n.lab_x.ln=1, n.lab_y.ln=1, xlab_adj=0, ylab_adj=0,
                     ...) {
+#   max.lbl <- max(nchar(axTicks(2)))
 
   lab_x_color <- ifelse(is.null(getOption("lab_x_color")),
     getOption("lab_color"), getOption("lab_x_color"))
@@ -1148,12 +1152,14 @@ function(dir, axT) {
 
   title(xlab=x.lab, line=lblx.lns-xlab_adj,
         col.lab=lab_x_color, cex.lab=lab_x_cex, ...)
-  title(sub=sub.lab, line=lblx.lns+1, cex.sub=0.76,
-        col.lab=lab_x_color, ...)
+  if (!is.null(sub.lab)) 
+    title(sub=sub.lab, line=lblx.lns+1, cex.sub=0.76,
+          col.lab=lab_x_color, ...)
   title(ylab=y.lab, line=lbly.lns-ylab_adj+.1,
         col.lab=lab_y_color, cex.lab=lab_y_cex, ...)
-  title(main=main.lab, cex.main= getOption("main_cex"),
-        col.main=getOption("main_color"), ...)
+  if (!is.null(main.lab)) 
+    title(main=main.lab, cex.main= getOption("main_cex"),
+          col.main=getOption("main_color"), ...)
 
 }
 
@@ -1548,7 +1554,7 @@ function(dir, axT) {
 }
 
 
-# get the name of a pre-set color range that links with the current theme
+# from the theme, get the name of the corresponding pre-set color range 
 .get_fill <- function(theme=getOption("theme"), seq.pal=TRUE) {
 
   # for ordinal variables, or color theme not default, get sequential palette
@@ -1573,7 +1579,8 @@ function(dir, axT) {
 }
 
 
-# generate a color palette from a pre-defined name
+# from a pre-defined color palette name, generate the palette
+# if not a palette name, then return the name, i.e., do nothing
 .color_range <- function(fill, n.clr) {
 
   # names of color palettes generated by getColors
@@ -1605,7 +1612,7 @@ function(dir, axT) {
         clrs <- getColors(fill[1], n=n.clr, output=FALSE)  # sequential palette
       }
       else {
-        clrs <- fill
+        clrs <- fill  # not an identified name of a color range
       }
 
       if (length(fill == 2)) {  # divergent
