@@ -1,13 +1,13 @@
 ## ----include=FALSE----------------------------------------------------------------------------------------------------
 suppressPackageStartupMessages(library("lessR"))
 
-## ---------------------------------------------------------------------------------------------------------------------
-d <- Read("Employee")
-
 ## ----pivot, dataTable, echo=FALSE, out.width='92%', fig.align='center', out.extra='style="border-style: none"'--------
 knitr::include_graphics(system.file("img", "pivot.png", package="lessR"))
 
-## ----echo=FALSE-------------------------------------------------------------------------------------------------------
+## ---------------------------------------------------------------------------------------------------------------------
+d <- Read("Employee")
+
+## ---------------------------------------------------------------------------------------------------------------------
 pivot(data=d, compute=mean, variable=Years, by=c(Dept, Gender))
 
 ## ---------------------------------------------------------------------------------------------------------------------
@@ -112,3 +112,9 @@ pivot(dd, c(mean,median), Years, c(Dept, Gender), na_by_show=TRUE)
 ## ---------------------------------------------------------------------------------------------------------------------
 pivot(dd, c(mean,median), Years, c(Dept, Gender), na_by_show=FALSE)
 
+## ---------------------------------------------------------------------------------------------------------------------
+mnmd = function(x, na.rm=TRUE)  mean(x, na.rm=na.rm) - median(x, na.rm=na.rm)
+
+## ---------------------------------------------------------------------------------------------------------------------
+pivot(d, c(mean, median, mnmd), Years, by=Dept)
+
